ConfigError

Type Alias ConfigError 

pub type ConfigError = Error;
This error is returned if there is something wrong with the SQLite configuration.

This is just a type alias to citadel::Error at the moment as there is no validation happening at the configuration phase.

Aliased Type

pub enum ConfigError {
Show 28 variants PageTampered(PageId), BadPassphrase, DatabaseLocked, KeyFileMismatch, TransactionTooLarge { capacity: usize, }, DatabaseCorrupted, ChecksumMismatch(PageId), InvalidPageType(u16, PageId), KeyTooLarge { size: usize, max: usize, }, ValueTooLarge { size: usize, max: usize, }, InvalidMagic { expected: u32, found: u32, }, UnsupportedVersion(u32), KeyFileIntegrity, InvalidKeyFileMagic, KeyUnwrapFailed, NoWriteTransaction, WriteTransactionActive, PageOutOfBounds(PageId), BufferPoolFull, UnsupportedCipher(u8), UnsupportedKdf(u8), FipsViolation(String), TableNotFound(String), TableAlreadyExists(String), PassphraseRequired, Sync(String), Io(Error), CorruptOverflowChain(String),
}

Variants



PageTampered(PageId)



BadPassphrase



DatabaseLocked



KeyFileMismatch



TransactionTooLarge

Fields

capacity: usize


DatabaseCorrupted



ChecksumMismatch(PageId)



InvalidPageType(u16, PageId)



KeyTooLarge

Fields

size: usize
max: usize


ValueTooLarge

Fields

size: usize
max: usize


InvalidMagic

Fields

expected: u32
found: u32


UnsupportedVersion(u32)



KeyFileIntegrity



InvalidKeyFileMagic



KeyUnwrapFailed



NoWriteTransaction



WriteTransactionActive



PageOutOfBounds(PageId)



BufferPoolFull



UnsupportedCipher(u8)



UnsupportedKdf(u8)



FipsViolation(String)



TableNotFound(String)



TableAlreadyExists(String)



PassphraseRequired



Sync(String)



Io(Error)



CorruptOverflowChain(String)